@@ -11,13 +11,11 @@ data_original<-data.frame(key = c(1:1000),
                           log_outcome = rnorm(n = 1000, mean = 8, sd = 1.4), 
                           treat = rep(c(rep(c(0,1,2,3), times = 10), rep(c(0,1,2,3), each = 10)), each = 25)) 
 
-# 1. Dimensiones 
-a<-ntile_label(data_original$inc, n = 4)
 
 test_that("ntile returns factor with n-classes", {
-  expect_is(a, "factor")
-  expect_equal(length(a), nrow(data_original))
-  expect_equal(length(levels(a)), 4)
+  expect_is(ntile_label(data_original$inc, n = 4), "factor")
+  expect_equal(length(ntile_label(data_original$inc, n = 4)), nrow(data_original))
+  expect_equal(length(levels(ntile_label(data_original$inc, n = 4))), 4)
   })
 
 
